==> openjpa-parent-2.4.3-source-release.zip: openjpa-parent-2.4.3/openjpa-jest/src/main/java/org/apache/openjpa/json/JSON.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

package org.apache.openjpa.json;

/**
 * A generic interface for a JSON encoded instance.
 * 
 * @author Pinaki Poddar
 *
 */
public interface JSON {
    /**
     * Render into a string buffer.
     * 
     * @param level level at which this instance is being rendered
     * @return a mutable buffer
     */
    public StringBuilder asString(int level);
    
    public static final char FIELD_SEPARATOR  = ',';
    public static final char MEMBER_SEPARATOR = ',';
    public static final char VALUE_SEPARATOR  = ':';
    public static final char IOR_SEPARTOR     = '-';
    public static final char QUOTE            = '"';
    public static final char SPACE            = ' ';
    public static final char OBJECT_START     = '{';
    public static final char OBJECT_END       = '}';
    public static final char ARRAY_START      = '[';
    public static final char ARRAY_END        = ']';
    
    public static final String NEWLINE        = "\r\n";
    public static final String NULL_LITERAL   = "null";
    public static final String REF_MARKER     = "$ref";
    public static final String ID_MARKER      = "$id";
    public static final String ARRAY_EMPTY    = "[]";
    
}

==> openjpa-parent-4.1.1-source-release.zip: openjpa-parent-4.1.1/openjpa-jest/src/main/java/org/apache/openjpa/json/JSON.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.openjpa.json;

/**
 * A generic interface for a JSON encoded instance.
 *
 * @author Pinaki Poddar
 *
 */
public interface JSON {
    /**
     * Render into a string buffer.
     *
     * @param level level at which this instance is being rendered
     * @return a mutable buffer
     */
    StringBuilder asString(int level);

    char FIELD_SEPARATOR  = ',';
    char MEMBER_SEPARATOR = ',';
    char VALUE_SEPARATOR  = ':';
    char IOR_SEPARTOR     = '-';
    char QUOTE            = '"';
    char SPACE            = ' ';
    char OBJECT_START     = '{';
    char OBJECT_END       = '}';
    char ARRAY_START      = '[';
    char ARRAY_END        = ']';

    String NEWLINE        = "\r\n";
    String NULL_LITERAL   = "null";
    String REF_MARKER     = "$ref";
    String ID_MARKER      = "$id";
    String ARRAY_EMPTY    = "[]";

}
